---
author: François Pelletier
title: Les principes FAIR
date: 28 novembre 2023
---

# Les principes FAIR

## Objectif

Rendre les données de recherche réutilisables par les individus et les machines.

## Enjeux actuels avec les données

### Données massives

- Volume
- Variété
- Vélocité
- Véracité
- Valeur

![donnees-massives.png](donnees-massives.png)

### Complexité des données

- Multidisciplinaires
- Méthodes et instruments complexes
- Logiciels et matériel requis
- Environnement légal et éthique

### Trouver ce qui existe déjà

- Trouver un article: 🎯
- Télécharger l'article: 📚, 💸 ou 🐦‍⬛
- Trouver les données qui vont avec: 🧗
- Ouvrir les données: 🤡

### Déplacer et stocker les données

À l'Université Laval, nous avons:

- Médias physiques: Livres, Microfiches, VHS, Disques
- Serveurs: Sites web, FTP, GLOBUS, S3, GitLab, Subversion
- Logiciels partagés Microsoft 365: SharePoint, Teams, ...

## Que signifie FAIR ?

- **F**indable (découvrable)
- **A**ccessible (accessible)
- **I**nteroperable (interoperable)
- **R**eusable (réutilisable)

### Définitions formelles

- FAIR a été défini par Wilkinson, M. D. et al. (2016)
- Le concept d'Open Data est défini par l'Open Knowledge Foundation, via la Définition du Savoir Libre.

## Qu'est-ce qui est concerné ?

Tous les actifs numériques produits par des activités de recherche

- Données quantitatives et qualitatives
- Figures
- Multimédia
- Texte
- Code informatique
- Protocole de recherche
- Plans et instructions de fabrication

## Les 4 lettres

### **F**indable (découvrable)

- Identifiant unique
  - DOI: Digital object identifier
    - Pour des actifs numériques de recherche
    - [DOI Handbook](https://doi.org/10.1000/182)
  - URI: Uniform Resource Identifier: 
    - Pour tout ce qui est accessible sur le web
    - Inclus tous les fichiers et pages web
    - S'applique aussi à des concepts et des entités.
    - Fondement du web sémantique (web 3.0)
- Métadonnées
  - Plus elles sont détaillées, plus elles renseignent les moteurs de recherche
    - [Schema.org](https://schema.org/): Guide de métadonnées et vocabulaires
    - [Wikidata](https://www.wikidata.org/): Un exemple de structure
- Indexation
  - Dépôts de données
    - [Borealis](https://borealisdata.ca/)
    - [Dataverse](https://dataverse.org/)
  - Moteurs de recherche
    - [Google Datasets](https://datasetsearch.research.google.com/)

### **A**ccessible (accessible)

- Métadonnées
  - Normalisées
  - Identifiant unique
  - Licence d'utilisation
    - [Open Database License](https://opendatacommons.org/licenses/odbl/)
    - [Creative Commons License](https://creativecommons.org/share-your-work/cclicenses/)
  - Protocole d'accès aux métadonnées
    - Caractéristiques
      - Libre: Aucune restriction d'usage
      - Ouvert: Documenté
      - Universel: Utilisable avec plusieurs médias
    - Permission: Authentification et Autorisation
    - Exemples: HTTPS, FTP, Courriel, Téléphone, Poste
- Indépendantes des données
  - Si les données expirent ou on reçoit une demande de suppression
  - Sensibilité des données (confidentiel)

### **I**nteroperable (interoperable)

- Représentation des connaissances
  - Formalisé
  - Accessible
  - Partagé
  - Applicables à plusieurs contextes
- Vocabulaire
  - Ontologies
  - FAIR aussi
- Références
  - Identifiants uniques
- Toile de données
  - LOD: Linked Open Data
- Concerne les données et les métadonnées

### **R**eusable (réutilisable)

- Description riche
- Source
  - Références
  - Lignage
  - Code informatique
  - Encodage
- Normes de pratique du domaine

## Pourquoi appliquer les principes FAIR

### Qualité

- Augmenter la qualité des données de recherche
  - Données complètes
  - Intégrité des données
  - Sources vérifiables
  - Éliminer la duplication
  - Validité (domaines de valeurs)
  - Temporalité (âge des données)

### Revalorisation

- Créer des collections de données de recherche

### Pérennité

- Assurer la pérennité des résultats de recherche et des publications.
- Reproductibilité
- Autonomie dans l'usage de données de recherche

### Méta-analyses

- L'interopérabilité permet de faire des méta-analyses sans devoir convertir les données dans d'autres formats ou trouver des équivalences de vocabulaire

### Cycle de vie

- Aider les chercheur.es à organiser leurs données tout au long du cycle de vie
- Gestion des consentements
- Facilite l'élaboration de plan de gestion de données
- Mise à jour des résultats

### Transparence

- Favoriser la reddition de compte et la demande de financement public
- Augmenter la valeur et l'impact à long terme de la recherche
  - Réduire les rétractations
  - Opinion publique

## Références

- Wilkinson, M. D. et al. The FAIR Guiding Principles for scientific data management and stewardship. Sci. Data 3:160018 doi: https://dx.doi.org/10.1038/sdata.2016.18 (2016).
- Open Knowledge Foundation. Définition du Savoir Libre. Version: 1.1 https://opendefinition.org/od/1.1/fr/
- Go FAIR. FAIR Principles
   https://www.go-fair.org/fair-principles/
- OpenAIRE. How to make your data FAIR. https://www.openaire.eu/how-to-make-your-data-fair